#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from __init__ import REPO

__all__ = ["name"]

# default pkgname
name = os.path.basename(REPO).lower().split(".")[0]


if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))



#!/usr/bin/env python
# setuptools setup(...,install_requires=[]) keyword
# checks that the requirements installed
# raise exception if requirements not installed:
# error: Could not find required distribution <name>
# fix - install requirements.txt first:
# 1) pip install -U <name>
# 2) pip install -r requirements.txt; python install setup.py
import os
from __init__ import REPO, readlines

__all__ = ["install_requires"]

filenames = ["requirements.txt", "requires.txt", "install_requires.txt"]
for filename in filenames:
    path = os.path.join(REPO, filename)
    if os.path.exists(path):
        install_requires = readlines(path)
        if install_requires:
            break

if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from __init__ import REPO, read

__all__ = ["url"]


path = os.path.join(REPO, "url.txt")
if os.path.exists(path) and os.path.isfile(path):
    url = read(path)
else:
    if __name__ == "__main__":
        print("SKIP: %s NOT EXISTS" % path)

if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from __init__ import REPO, load_module

__all__ = ["data_files"]

data_files = []
path = os.path.join(REPO, "data_files.py")
if os.path.exists(path):
    module = load_module(path)
    if hasattr(module, "data_files"):
        data_files = module.data_files
else:
    if __name__ == "__main__":
        print("SKIP: %s NOT EXISTS" % path)

if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))



#!/usr/bin/env python
# setuptools setup(...,dependency_links=[]) keyword
import os
from __init__ import REPO, readlines

__all__ = ["dependency_links"]

dependency_links = []
filenames = ["dependency_links.txt", "dependency.txt"]
for filename in filenames:
    path = os.path.join(REPO, filename)
    dependency_links += readlines(path)

if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))



#!/usr/bin/env python
# setuptools setup(...,entry_points=[]) keyword
import os
from __init__ import REPO, readlines

__all__ = ["entry_points"]

# ./entry_points.txt
path = os.path.join(REPO, "entry_points.txt")
if os.path.exists(path) and os.path.isfile(path):
    entry_points = readlines(path)
else:
    if __name__ == "__main__":
        print("SKIP: %s NOT EXISTS" % path)

if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from __init__ import REPO, read

__all__ = ["description"]

description = None
filenames = ["description", "description.txt"]
# ./description, ./description.txt
for filename in filenames:
    path = os.path.join(REPO, filename)
    if os.path.exists(path) and os.path.isfile(path):
        description = read(path)
if description is None and __name__ == "__main__":
    print("SKIP: %s NOT EXISTS" % ", ".join(filenames))

if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from __init__ import REPO, read

__all__ = ["long_description"]

for name in ["README.rst", "README", "README.txt"]:
    fullpath = os.path.join(REPO, name)
    if not os.path.exists(fullpath):
        continue
    if not os.path.isfile(fullpath):
        continue
    long_description = read(fullpath)
    break

if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from __init__ import REPO

__all__ = ["py_modules", "package_dir"]


def _py_modules(path):
    listdir = os.listdir(path)
    for l in listdir:
        if os.path.splitext(l)[1] != ".py":
            continue
        fullpath = os.path.join(path, l)
        if not os.path.isfile(fullpath):
            continue
        yield l.replace(".py", "")

path = os.path.join(REPO, "py_modules")
if os.path.exists(path) and os.path.isdir(path):  # ./py_modules/
    py_modules = list(_py_modules(path))
    if py_modules:
        package_dir = {'': "py_modules"}
else:
    if __name__ == "__main__":
        print("SKIP: %s/ NOT EXISTS" % path)

if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from __init__ import REPO

__all__ = ["packages", "package_dir", "package_data"]

# distname.py/
# distname.py/packages/
# distname.py/packages/pkgname1/
# distname.py/packages/pkgname2/


def _packages(path):
    listdir = os.listdir(path)
    for l in listdir:
        if os.path.exists(os.path.join(path, l, "__init__.py")):
            yield l

path = os.path.join(REPO, "packages")
if os.path.exists(path) and os.path.isdir(path):
    packages = list(_packages(path))
    if packages:
        package_dir = dict()
        package_data = dict()
        for package in packages:
            package_dir[package] = "packages/%s" % package
            package_data[package] = ['*']
else:
    if __name__ == "__main__":
        print("SKIP: %s/ NOT EXISTS" % path)

if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from __init__ import REPO, readlines

__all__ = ["classifiers"]

HOME = os.environ["HOME"]

classifiers = []
# ~/.classifiers.txt (default)
# ./.classifiers.txt, ./classifiers.txt (custom)
for path in [
        os.path.join(HOME, ".classifiers.txt"),
        os.path.join(REPO, ".classifiers.txt"),
        os.path.join(REPO, "classifiers.txt")]:
    if os.path.exists(path) and os.path.isfile(path):
        for l in readlines(path):
            if l and " :: " in l and "#" not in l:
                classifiers.append(l)
classifiers = sorted(list(set(classifiers)))

if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import sys

__all__ = []

# repo/setup.py 		(this file)
# repo/.setup/__init.py (imported by setup.py)
# repo/.setup/.*.py 	(imported by __init__.py)

# exclude .pyc, __pycache__/ (python3+)
# disable byte compiling:
# 	1) sys.dont_write_bytecode = True
# 	2) python -B setup.py
# 	3) PYTHONDONTWRITEBYTECODE=true (enviroment variable)
# MANIFEST.in:
# 	global-exclude *.py[co]
# 	exclude __pycache__/*

REPO = os.path.abspath(os.path.dirname(__file__))

setup = os.path.join(REPO, ".setup")
if os.path.exists(setup) and os.path.isdir(setup):
    sys.path.append(setup)
else:
    raise Exception("%s NOT EXISTS" % setup)

if __name__ == "__main__":
    __import__("__init__").main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import imp
import os
import sys
import warnings

__all__ = ["REPO", "read", "readlines", "load_module"]

REPO = os.path.abspath(os.path.dirname(os.path.dirname(__file__)))


def read(path):
    if os.path.exists(path) and os.path.isfile(path):
        value = open(path).read().lstrip().rstrip()
        if value:
            return value


def readlines(path):
    if os.path.exists(path) and os.path.isfile(path):
        lines = open(path).read().splitlines()
        lines = list(filter(lambda l: l.lstrip().rstrip(), lines))
        lines = list(filter(lambda l: l, lines))
        return lines
    return []


def _pyfiles(path):
    """find python files of a directory"""
    listdir = os.listdir(path)
    listdir = filter(lambda l: os.path.splitext(
        l)[1] == ".py" and l.find("__") < 0, listdir)
    return listdir


def moduledict(module):
    """get module public objects dict"""
    kwargs = dict()
    for k in getattr(module, "__all__"):
        if getattr(module, k):
            kwargs[k] = getattr(module, k)
    return kwargs


def load_module(path):
    with open(path, 'rb') as fhandler:
        # .hidden.py invisible for mdfind
        module = imp.load_module(
            path, fhandler, path, ('.py', 'rb', imp.PY_SOURCE))
        # __all__ required
        if not hasattr(module, '__all__'):
            raise ValueError("ERROR: %s __all__ required" % path)
        return module


def _update(**kwargs):
    for key, value in kwargs.items():
        if key not in sys.modules["__main__"].__all__:
            sys.modules["__main__"].__all__.append(key)
        setattr(sys.modules["__main__"], key, value)


def isstring(value):
    try:
        int(value)
        return False
    except ValueError:
        return True
    except Exception:
        return False


def info(string):
    if len(sys.argv) == 1:
        print(string)


def main():
    sys.modules["__main__"].__all__ = []
    os.chdir(REPO)

    _setup = os.path.abspath(os.path.dirname(__file__))
    files = _pyfiles(_setup)
    # RuntimeWarning: Parent module 'modname' not found while handling
    # absolute import
    warnings.simplefilter("ignore", RuntimeWarning)

    for file in files:
        try:
            fullpath = os.path.join(_setup, file)
            module = load_module(fullpath)
            kwargs = moduledict(module)
            _update(**kwargs)
            if kwargs:
                info(".setup/%s: %s" % (file[1:], kwargs))
        except AttributeError:  # variable from __all__ not initialized
            continue
    # ~/.setup_kwargs.py
    fullpath = os.path.join(os.environ["HOME"], ".setup_kwargs.py")
    if os.path.exists(fullpath):
        module = load_module(fullpath)
        setup_kwargs = moduledict(module)

        _update(**setup_kwargs)
        info("%s: %s" % ("~/.setup_kwargs.py", setup_kwargs))
    else:
        info("SKIP: %s NOT EXISTS" % fullpath)

    kwargs = moduledict(sys.modules["__main__"])
    if "name" in kwargs:
        name = kwargs["name"]
        del kwargs["name"]

    if len(sys.argv) == 1 and kwargs:  # debug
        print('\nsetup(name="%s",' % name)
        for i, key in enumerate(sorted(list(kwargs.keys())), 1):  # python3
            value = kwargs[key]
            str_value = '"%s"' % value if isstring(value) else value
            comma = "," if i != len(kwargs) else ""
            print("    %s = %s%s" % (key, str_value, comma))
        print(')')

    # 1) distutils (Python Standart Library)
    #   https://docs.python.org/2/distutils/setupscript.html
    #   https://docs.python.org/2/distutils/apiref.html (arguments)
    # 2) setuptools (extra commands and arguments)
    #   extra commands:
    # http://pythonhosted.org/setuptools/setuptools.html#command-reference
    #   extra arguments:
    # http://pythonhosted.org/setuptools/setuptools.html#new-and-changed-setup-keywords
    setuptools = True
    if "--manifest-only" in sys.argv:  # distutils only
        setuptools = False
    if setuptools:
        try:
            import setuptools
            if "install" in sys.argv:
                print("setuptools.__version__: %s" % setuptools.__version__)
            setup = setuptools.setup
            if "zip_safe" not in kwargs:
                kwargs["zip_safe"] = False
        except ImportError:
            setuptools = False
    if not setuptools:
        if "install" in sys.argv:
            import distutils
            print("distutils.__version__: %s" % distutils.__version__)
        from distutils.core import setup

    if len(sys.argv) == 1:
        return
    setup(name=name, **kwargs)

if __name__ == "__main__":
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
from __init__ import REPO

__all__ = ["scripts"]


def valid_script_name(name):
    if name[0] == ".":  # skip .hidden files
        return False
    if " " in name:  # skip filename with ' ' space
        return False
    if ".txt" in name:  # skip .txt files
        return False
    return True


def _scripts(path):
    listdir = os.listdir(path)
    for l in listdir:
        if not valid_script_name(l):
            continue
        dst = os.path.join("/usr/local/bin/%s" % l)
        if os.path.exists(dst) and not os.path.isfile(dst):
            raise OSError("ERROR: %s EXISTS and NOT FILE" % dst)
        fullpath = os.path.join(path, l)
        if os.path.isfile(fullpath):
            yield os.path.join(folder, l)

folder = "bin"
path = os.path.join(REPO, folder)
if os.path.exists(path) and os.path.isdir(path):
    scripts = list(_scripts(path))
else:
    if __name__ == "__main__":
        print("SKIP: %s/ NOT EXISTS" % path)

if __name__ == "__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k, globals()[k]))
